@@ -2,36 +2,36 @@
 #'
 #' @description Order rows in ascending or descending order
 #'
-#' @param .data A data.frame or data.table
+#' @param .df A data.frame or data.table
 #' @param ... Variables to arrange by
 #'
 #' @export
 #'
 #' @examples
-#' example_dt <- tidytable(
+#' test_df <- data.table(
 #'   a = c(1,2,3),
 #'   b = c(4,5,6),
 #'   c = c("a","a","b"))
 #'
-#' example_dt %>%
+#' test_df %>%
 #'   arrange.(c, -a)
 #'
-#' example_dt %>%
+#' test_df %>%
 #'   arrange.(c, desc.(a))
-arrange. <- function(.data, ...) {
+arrange. <- function(.df, ...) {
   UseMethod("arrange.")
 }
 
 #' @export
-arrange..data.frame <- function(.data, ...) {
+arrange..data.frame <- function(.df, ...) {
 
-  .data <- as_tidytable(.data)
+  .df <- as_tidytable(.df)
 
-  dots <- enexprs(...)
+  dots <- enquos(...)
 
-  eval_expr(
-    .data[order(!!!dots)]
-  )
+  eval_tidy(quo_squash(quo(
+    .df[order(!!!dots)]
+  )), .df)
 }
 
 #' @export
