@@ -12,8 +12,8 @@
 #' @md
 #'
 #' @examples
-#' df1 <- data.table::data.table(x = c(1,2,3), y = c(3,4,5))
-#' df2 <- data.table::data.table(x = c(1,2,3), y = c(3,4,5))
+#' df1 <- data.table(x = c(1,2,3), y = c(3,4,5))
+#' df2 <- data.table(x = c(1,2,3), y = c(3,4,5))
 #'
 #' df1 %>%
 #'   bind_rows.(df2)
@@ -24,12 +24,8 @@
 #'   bind_cols.(df2)
 #'
 #' bind_cols.(list(df1, df2))
-bind_rows. <- function(..., .id = NULL, use.names = TRUE, fill = TRUE) {
-  UseMethod("bind_rows.")
-}
-
 #' @export
-bind_rows..default <- function(..., .id = NULL, use.names = TRUE, fill = TRUE) {
+bind_rows. <- function(..., .id = NULL, use.names = TRUE, fill = TRUE) {
 
   dots <- list(...)
   dots <- squash(dots)
@@ -49,11 +45,6 @@ dt_bind_rows <- bind_rows.
 #' @export
 #' @rdname bind_rows.
 bind_cols. <- function(...) {
-  UseMethod("bind_cols.")
-}
-
-#' @export
-bind_cols..default <- function(...) {
 
   dots <- list(...)
   dots <- squash(dots)
