@@ -27,7 +27,7 @@
 #'   mutate.(x = case.(c == "a", "a",
 #'                     default = d))
 case. <- function(..., default = NA) {
-  dots <- enexprs(...)
+  dots <- enquos(...)
   dots_length <- length(dots)
 
   index <- '+'(1, 1:dots_length) %% 2
@@ -44,13 +44,13 @@ case. <- function(..., default = NA) {
   calls <- default
 
   for (i in rev(seq_along(conditions))) {
-    change_flag <- fifelse(eval(conditions[[i]], parent.frame()),
-                           TRUE, FALSE, FALSE)
-
-    calls <- call("ifelse.", change_flag, values[[i]], calls)
+    calls <- call("ifelse.",
+                  quo(rlang::'%|%'(!!conditions[[i]], FALSE)),
+                  values[[i]],
+                  calls)
   }
 
-  eval(calls, envir = parent.frame())
+  eval_tidy(calls)
 }
 
 #' @export
