@@ -3,53 +3,51 @@
 #' @description
 #' Aggregate data using summary statistics such as mean or median. Can be calculated by group.
 #'
-#' @param .data A data.frame or data.table
+#' @param .df A data.frame or data.table
 #' @param ... Aggregations to perform
 #' @param by Columns to group by.
 #' * A single column can be passed with `by = d`.
-#' * Multiple columns can be passed with `by = c(c, d)` or `by = list(c, d)`
+#' * Multiple columns can be passed with `by = c(c, d)`
 #' * `tidyselect` can be used:
-#'   + Single predicate: `by = is.character`
-#'   + Multiple predicates: `by = c(is.character, is.factor)`
-#'   + A combination of predicates and column names: `by = c(is.character, b)`
+#'   + Single predicate: `by = where(is.character)`
+#'   + Multiple predicates: `by = c(where(is.character), where(is.factor))`
+#'   + A combination of predicates and column names: `by = c(where(is.character), b)`
 #'
 #' @export
 #' @md
 #' @examples
-#' example_dt <- data.table::data.table(
+#' test_df <- data.table(
 #'   a = c(1,2,3),
 #'   b = c(4,5,6),
 #'   c = c("a","a","b"),
 #'   d = c("a","a","b"))
 #'
-#' example_dt %>%
+#' test_df %>%
 #'   summarize.(avg_a = mean(a),
 #'              max_b = max(b),
 #'              by = c)
 #'
-#' example_dt %>%
+#' test_df %>%
 #'   summarize.(avg_a = mean(a),
 #'              by = c(c, d))
-summarize. <- function(.data, ..., by = NULL) {
+summarize. <- function(.df, ..., by = NULL) {
   UseMethod("summarize.")
 }
 
 #' @export
-summarize..data.frame <- function(.data, ..., by = NULL) {
+summarize..data.frame <- function(.df, ..., by = NULL) {
 
-  .data <- as_tidytable(.data)
+  .df <- as_tidytable(.df)
 
-  dots <- enexprs(...)
-  by <- enexpr(by)
-  by <- vec_selector_by(.data, !!by)
+  dots <- enquos(...)
+  by <- select_vec_by(.df, {{ by }})
 
-  # Needed so n.() works
-  # Puts () around each summary function
-  dots <- map.(dots, ~ parse_expr(str_c("(", deparse(.x), ")")))
+  eval_quo(
+    .df[, eval_quo(
+      {.N = .env$.N; .SD = .env$.SD; .I = .env$.I; .GRP = .env$.GRP;
+      list(!!!dots)}, .SD), by = !!by],
+    .df)
 
-  eval_expr(
-    .data[, list(!!!dots), by = !!by]
-  )
 }
 
 #' @export
