@@ -37,9 +37,23 @@ test_that("distinct.() works on 1 column", {
 test_that("distinct.() works with enhanced selection", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.(is.character)
+    distinct.(where(is.character))
 
   expect_named(distinct_df, c("c", "d"))
   expect_equal(distinct_df$c, c("a", "b"))
   expect_equal(distinct_df$d, c("a", "b"))
 })
+
+test_that("can make a function with quosures", {
+  test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "b"), d = c("a", "a", "b"))
+
+  distinct_fn <- function(.df, col) {
+    .df %>%
+      distinct.({{col}})
+  }
+  distinct_df <- test_df %>%
+    distinct_fn(b)
+
+  expect_named(distinct_df, c("b"))
+  expect_equal(test_df$b, 4:6)
+})
